@@ -5,8 +5,8 @@ class ConectividadeAppConfig(PluginConfig):
     name = 'conectividadeapp'
     verbose_name = 'conectividade'
     description = 'An plugin'
-    version = '0.10'
-    author = 'Johnny, Avando, Eduardo.'
+    version = '0.0.32'
+    author = 'Johnny; Avando; Eduardo; Rary'
     author_email = 'johnnyyuri56@gmail.com'
     required_settings = []
     default_settings = {
