@@ -17,4 +17,4 @@ class OldDevice(admin.ModelAdmin):
 
 @admin.register(Actor)
 class ActorAdmin(admin.ModelAdmin):
-   list_display = ('id', 'name')
+    list_display = ['id', 'name']
